summaryrefslogtreecommitdiff
path: root/lib/dpif-provider.h
diff options
context:
space:
mode:
authorBen Pfaff <blp@nicira.com>2010-12-10 10:40:58 -0800
committerBen Pfaff <blp@nicira.com>2010-12-10 11:13:32 -0800
commitcdee00fd635d1e0f1eeb5d9c009daeb59abd4777 (patch)
tree49ef94d30bcb995fa1070c3aa770a9a515b26b0a /lib/dpif-provider.h
parent7f8ca6459c37ede8faf13f730bcd4d9f05dfd13b (diff)
downloadopenvswitch-cdee00fd635d1e0f1eeb5d9c009daeb59abd4777.tar.gz
datapath: Replace "struct odp_action" by Netlink attributes.
In the medium term, we plan to migrate the datapath to use Netlink as its communication channel. In the short term, we need to be able to have actions with 64-bit arguments but "struct odp_action" only has room for 48 bits. So this patch shifts to variable-length arguments using Netlink attributes, which starts in on the Netlink transition and makes 64-bit arguments possible at the same time. Signed-off-by: Ben Pfaff <blp@nicira.com> Acked-by: Jesse Gross <jesse@nicira.com>
Diffstat (limited to 'lib/dpif-provider.h')
-rw-r--r--lib/dpif-provider.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/lib/dpif-provider.h b/lib/dpif-provider.h
index 26cd6b099..deb3bf283 100644
--- a/lib/dpif-provider.h
+++ b/lib/dpif-provider.h
@@ -247,11 +247,10 @@ struct dpif_class {
* 'n' flows). On failure, returns a negative errno value. */
int (*flow_list)(const struct dpif *dpif, struct odp_flow flows[], int n);
- /* Performs the 'n_actions' actions in 'actions' on the Ethernet frame
- * specified in 'packet'. */
- int (*execute)(struct dpif *dpif,
- const union odp_action actions[], int n_actions,
- const struct ofpbuf *packet);
+ /* Performs the 'actions_len' bytes of actions in 'actions' on the Ethernet
+ * frame specified in 'packet'. */
+ int (*execute)(struct dpif *dpif, const struct nlattr *actions,
+ size_t actions_len, const struct ofpbuf *packet);
/* Retrieves 'dpif''s "listen mask" into '*listen_mask'. Each ODPL_* bit
* set in '*listen_mask' indicates the 'dpif' will receive messages of the